note
	description: "[
		Test examples with arrays and regular expressions.
		First test fails as Result is False by default.
		Write your own tests.
		Included libraries:
			base and extension
			Espec unit testing
			Mathmodels
			Gobo structures
			Gobo regular expressions
		]"
	author: "JSO"
	date: "$Date$"
	revision: "$Revision 19.05$"

class
	TEST_UTILITIES

inherit

	ES_TEST

create
	make

feature {NONE} -- Initialization

	make
			-- initialize tests
		do
			add_boolean_case (agent t0)
			add_boolean_case (agent t1)
			add_violation_case_with_tag ("array_sorted", agent t2)
			add_boolean_case (agent t3)
		end

feature -- tests

	t0: BOOLEAN
		local
			u: UTILITIES_V3
			a: ARRAY[STRING]
		do
			comment ("t1: test search (no precondition, correct implementation)")
			create u
			a := <<"c", "f", "h", "l", "o", "r", "v">>

			Result := u.search (a, "c")
			check Result end

			Result := u.search (a, "f")
			check Result end

			Result := u.search (a, "h")
			check Result end

			Result := u.search (a, "l")
			check Result end

			Result := u.search (a, "o")
			check Result end

			Result := u.search (a, "r")
			check Result end

			Result := u.search (a, "v")
			check Result end

			Result := not u.search (a, "a")
			check Result end

			Result := not u.search (a, "y")
			check Result end

			Result := not u.search (a, "m")
			check Result end
		end

	t1: BOOLEAN
		local
			db: DATABASE_V1
		do
			comment ("t1: test database V1 (wrong behaviour)")
			create db.make
			db.add_name ("e")
			db.add_name ("c")
			db.add_name ("d")
			db.add_name ("a")
			db.add_name ("b")

			-- incorrect behaviour
			Result := not db.data_exists ("a")
			check Result end

			-- incorrect behaviour
			Result := not db.data_exists ("b")
			check Result end

			-- incorrect behaviour
			Result := not db.data_exists ("c")
			check Result end

			Result := db.data_exists ("d")
			check Result end

			-- incorrect behaviour
			Result := not db.data_exists ("e")
			check Result end

			Result := not db.data_exists ("f")
			check Result end

			Result := not db.data_exists ("g")
			check Result end
		end

	t2
		local
			db: DATABASE_V2
			exists: BOOLEAN
		do
			comment ("t2: test database V2 (precondition violation)")
			create db.make
			db.add_name ("e")
			db.add_name ("c")
			db.add_name ("d")
			db.add_name ("a")
			db.add_name ("b")

			exists := db.data_exists ("a")
		end

	t3: BOOLEAN
		local
			db: DATABASE_V3
		do
			comment ("t3: test database V3 (correct behaviour)")
			create db.make
			db.add_name ("e")
			db.add_name ("c")
			db.add_name ("d")
			db.add_name ("a")
			db.add_name ("b")

			Result := db.data_exists ("a")
			check Result end

			Result := db.data_exists ("b")
			check Result end

			Result := db.data_exists ("c")
			check Result end

			Result := db.data_exists ("d")
			check Result end

			Result := db.data_exists ("e")
			check Result end

			Result := not db.data_exists ("f")
			check Result end

			Result := not db.data_exists ("g")
			check Result end
		end

end
